reconstruct

Function reconstruct 

pub fn reconstruct(pages: &[Page]) -> Document
Turn a page’s raw text spans into the semantic Document AST: split each page into reading-order columns, group spans into lines, then classify each line (or run of lines) as a heading, list, table, figure caption, or paragraph.